@@ -11,9 +11,6 @@
 #MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #GNU General Public License for more details
 
-echo "Hinemos starting"
-echo ""
-
 # check for incorrect user
 
 EXEC_USER=`/usr/bin/whoami`
@@ -26,6 +23,25 @@ fi
 
 . /opt/hinemos/hinemos.cfg
 
+# check on option
+for OPTION in "$@"
+do
+	case $OPTION in
+		-c)
+			OPT=-c
+			;;
+		*)
+			echo "usage"
+			echo "hinemos_start.sh    : Hinemos is started as usual. "
+			echo "hinemos_start.sh -c : After the JMS message is annulled, JBoss is started. "
+			exit 1
+			;;
+	esac
+done
+
+echo "Hinemos starting"
+echo ""
+
 # Start up PostgreSQL
 
 ${HINEMOS_HOME}/bin/pg_start.sh
@@ -51,11 +67,13 @@ echo ""
 #Start up JBoss
 
 #echo -n "waiting for jboss to start";
-${HINEMOS_HOME}/bin/jboss_start.sh
+
+${HINEMOS_HOME}/bin/jboss_start.sh $OPT
 
 REVAL=$?
 if [ "$REVAL" -ne 0 -a "$REVAL" -ne 24 ] ; then
-        exit 1
+	echo "Hinemos didn't start"
+    exit 1
 fi
 
 echo "Hinemos started"
