@@ -11,6 +11,7 @@
 #MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #GNU General Public License for more details
 
+FAILURE_MESSAGE="Hinemos stop fails."
 
 echo "Hinemos stopping."
 
@@ -27,9 +28,12 @@ fi
 
 ${HINEMOS_HOME}/bin/jboss_stop.sh 2> /dev/null
 REVAL=$?
-if [ $REVAL -ne 0 ]; then
+if [ $REVAL -eq 1 ]; then
     echo ""
     echo "JBoss stop fails."   
+    echo ""
+	echo ${FAILURE_MESSAGE}
+	exit 1
 fi
 echo ""
 
@@ -39,6 +43,9 @@ REVAL=$?
 if [ $REVAL -ne 0 ]; then
     echo ""
     echo "slpad stop fails."
+    echo ""
+	echo ${FAILURE_MESSAGE}
+	exit 1
 fi
 echo ""
 
@@ -48,6 +55,9 @@ REVAL=$?
 if [ $REVAL -ne 0 ]; then
     echo ""
     echo "postmaster stop fails"
+    echo ""
+	echo ${FAILURE_MESSAGE}
+	exit 1
 fi
 echo ""
 
