@@ -10,12 +10,12 @@ PWD_PROC="/bin/pwd"
 LS_PROC="/bin/ls"
 RM_PROC="/bin/rm -rf"
 
-AGENT_HOME="/opt/hinemos_agent"
-AGENT_DIR="Hinemos_Agent-2.2.1_rhel4"
-AGENT_INSTALL_SH="agent_installer_JP.sh"
-AGENT_ARC="hinemos_agent-2.2.1_rhel4.tar.gz"
+HINEMOS_VERSION=%%hinemos_version%%
 JRE_VERSION="%%jre_version%%"
 
+AGENT_HOME="/opt/hinemos_agent"
+AGENT_INSTALL_SH="agent_installer_JP.sh"
+
 # 変数
 ip_address=""
 pass=""
@@ -23,6 +23,7 @@ agent=""
 jre_ans=""
 col=""
 place=""
+architecture=""
 
 ##
 ## 引数格納
@@ -60,6 +61,10 @@ do
       fi
       place=$1
       ;;
+    -o)
+      shift
+      architecture=$1
+      ;;
     *)
       ;;
   esac
@@ -68,6 +73,9 @@ do
 
 done
 
+AGENT_DIR="Hinemos_Agent-${HINEMOS_VERSION}_${architecture}"
+AGENT_ARC="hinemos_agent-${HINEMOS_VERSION}_${architecture}.tar.gz"
+
 
 ##
 ## 確認
